@@ -1,4 +1,5 @@
 from django_filters import rest_framework as filters
+from ..files.views import FileSerializer
 from rest_framework import serializers, viewsets
 from django.db.models.query_utils import Q
 from .models import User, UserRoleWorkspace
@@ -19,14 +20,28 @@ class UserSerializer(serializers.ModelSerializer):
             "first_name",
             "last_name",
             "created",
+            "avatar",
             "is_superuser",
             "modified",
             "generic_groups",
             "user_role_workspaces",
+            "password",
         ]
         model = User
+        extra_kwargs = {
+            'password': {
+                'write_only': True
+            }
+        }
+
     user_role_workspaces = UserRoleWorkspaceSerializer(many=True)
 
+    # We show full avatar in formation on get, on update we only use doc id
+    def to_representation(self, instance):
+        response = super().to_representation(instance)
+        response['avatar'] = FileSerializer(instance.avatar).data if instance.avatar else None
+        return response
+
     def update(self, instance, validated_data):
         if 'user_role_workspaces' in validated_data:
             user_role_workspaces_data = validated_data.pop('user_role_workspaces')
@@ -40,7 +55,11 @@ class UserSerializer(serializers.ModelSerializer):
             # remove removed rights
             UserRoleWorkspace.objects.filter(user=instance).exclude(workspace__in=user_workspaces).delete()
 
-        return super(self.__class__, self).update(instance, validated_data)
+        user = super(self.__class__, self).update(instance, validated_data)
+        if 'password' in validated_data:
+            user.set_password(validated_data['password'])
+            user.save()
+        return user
 
     def create(self, validated_data):
         user_role_workspaces_data = validated_data.pop('user_role_workspaces')
@@ -49,6 +68,9 @@ class UserSerializer(serializers.ModelSerializer):
             UserRoleWorkspace.objects.create(
                 user=user, **user_role_workspace_data
             )
+        if 'password' in validated_data:
+            user.set_password(validated_data['password'])
+            user.save()
         return user
 
 
